import { useEffect, useRef } from 'react'

function useEventListener(eventName, handler, el) {
  const element = useRef()
  const savedHandler = useRef()

  useEffect(() => {
    savedHandler.current = handler
  }, [handler])

  useEffect(
    () => {
      if (typeof window === 'undefined') return

      element.current = el || window

      // Make sure element supports addEventListener
      const isSupported = element && element.addEventListener

      if (!isSupported) return

      // Create event listener that calls handler function stored in ref
      const eventListener = (event) => savedHandler.current(event)

      // Add event listener
      element.addEventListener(eventName, eventListener)

      // Remove event listener on cleanup
      return () => {
        element.removeEventListener(eventName, eventListener)
      }
    },
    [eventName, el] // Re-run if eventName or element changes
  )
}

export default useEventListener
